% Auto-generated chapter 34 for ibnmajah
% Hadiths in this chapter: 66

\hadithdefcmd{ibnmajah}{3827}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبُو الْمَلِيحِ الْمَدَنِيُّ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَمْ يَدْعُ اللَّهَ سُبْحَانَهُ غَضِبَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3827}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the :Messenger of Allah (saas) said: "Whoever does not call upon Allah, He will be angry with him}}
\hadithdefcmd{ibnmajah}{3828}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ ذَرِّ بْنِ عَبْدِ اللَّهِ الْهَمْدَانِيِّ، عَنْ يُسَيْعٍ الْكِنْدِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ الدُّعَاءَ هُوَ الْعِبَادَةُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{وَقَالَ رَبُّكُمُ ادْعُونِي أَسْتَجِبْ لَكُمْ\}‏ ‏.‏\hadithno{3828}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Nu'man bin Bashir that :the Messenger of Allah (saas) said: "Indeed the supplication is the worship." Then he recited: "And your Lord said: Invoke Me, I will respond to you}}
\hadithdefcmd{ibnmajah}{3829}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَيْسَ شَىْءٌ أَكْرَمَ عَلَى اللَّهِ سُبْحَانَهُ مِنَ الدُّعَاءِ ‏"‏ ‏.‏\hadithno{3829}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that :the Prophet (saas) said: "There is nothing more noble to Allah the Glorified, than supplication}}
\hadithdefcmd{ibnmajah}{3830}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، سَنَةَ إِحْدَى وَثَلاَثِينَ وَمِائَتَيْنِ حَدَّثَنَا وَكِيعٌ، فِي سَنَةِ خَمْسٍ وَتِسْعِينَ وَمِائَةٍ قَالَ حَدَّثَنَا سُفْيَانُ فِي مَجْلِسِ الأَعْمَشِ مُنْذُ خَمْسِينَ سَنَةً حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ الْجَمَلِيُّ فِي زَمَنِ خَالِدٍ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ الْمُكْتِبِ عَنْ طَلِيقِ بْنِ قَيْسٍ الْحَنَفِيِّ عَنِ ابْنِ عَبَّاسٍ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ فِي دُعَائِهِ ‏ "‏ رَبِّ أَعِنِّي وَلاَ تُعِنْ عَلَىَّ وَانْصُرْنِي وَلاَ تَنْصُرْ عَلَىَّ وَامْكُرْ لِي وَلاَ تَمْكُرْ عَلَىَّ وَاهْدِنِي وَيَسِّرِ الْهُدَى لِي وَانْصُرْنِي عَلَى مَنْ بَغَى عَلَىَّ رَبِّ اجْعَلْنِي لَكَ شَكَّارًا لَكَ ذَكَّارًا لَكَ رَهَّابًا لَكَ مُطِيعًا إِلَيْكَ مُخْبِتًا إِلَيْكَ أَوَّاهًا مُنِيبًا رَبِّ تَقَبَّلْ تَوْبَتِي وَاغْسِلْ حَوْبَتِي وَأَجِبْ دَعْوَتِي وَاهْدِ قَلْبِي وَسَدِّدْ لِسَانِي وَثَبِّتْ حُجَّتِي وَاسْلُلْ سَخِيمَةَ قَلْبِي ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ الطَّنَافِسِيُّ قُلْتُ لِوَكِيعٍ أَقُولُهُ فِي قُنُوتِ الْوِتْرِ قَالَ نَعَمْ ‏.‏\hadithno{3830}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that :the Prophet (saas) used to say in his supplication: "Rabbi! A'inni wa la tu'in 'alayya, wansurni wa la tansur 'alayya, wamkurli wa la tamkur 'alayya, wahdini wa yassiril-huda li, wansurni 'ala man bagha 'alayya. Rabbij'alni laka shakkaran laka dhakkaran, laka rahhaban, laka muti'an, 'ilayka mukhbitan, 'ilayka awwahan muniba. Rabbi! Taqabbal tawbati, waghsil hawbati wa ajib da'wati, wahdi qalbi, wa saddid lisani, wa thabbit hujjati, waslul sakhimata qalbi (O Lord! Help me and do not help others against me, support me and do not support others against me, plan for me and do not plan against me, guide me and make guidance easy for me, and help me against those who wrong me. O Lord! Make me grateful to You, make me remember You much, make me fearful of You, obedient to You, humble before You and turning to You. O Lord! Accept my repentance and wash away my sins, answer my supplication, guide my heart, make my tongue speak the truth, make my proof firm and remove resentment from my heard)." (Sahih)(One of the narrators) Abul-Hasan At-Tanafisi said: "I said to Waki': 'Shall I say it in the Qunut of Witr?' He said: 'Yes}}
\hadithdefcmd{ibnmajah}{3831}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُبَيْدَةَ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَتْ فَاطِمَةُ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَسْأَلُهُ خَادِمًا فَقَالَ لَهَا ‏"‏ مَا عِنْدِي مَا أُعْطِيكِ ‏"‏ ‏.‏ فَرَجَعَتْ فَأَتَاهَا بَعْدَ ذَلِكَ فَقَالَ ‏"‏ الَّذِي سَأَلْتِ أَحَبُّ إِلَيْكِ أَوْ مَا هُوَ خَيْرٌ مِنْهُ ‏"‏ ‏.‏ فَقَالَ لَهَا عَلِيٌّ قُولِي لاَ بَلْ مَا هُوَ خَيْرٌ مِنْهُ فَقَالَتْ فَقَالَ ‏"‏ قُولِي اللَّهُمَّ رَبَّ السَّمَوَاتِ السَّبْعِ وَرَبَّ الْعَرْشِ الْعَظِيمِ رَبَّنَا وَرَبَّ كُلِّ شَىْءٍ مُنْزِلَ التَّوْرَاةِ وَالإِنْجِيلِ وَالْقُرْآنِ الْعَظِيمِ أَنْتَ الأَوَّلُ فَلَيْسَ قَبْلَكَ شَىْءٌ وَأَنْتَ الآخِرُ فَلَيْسَ بَعْدَكَ شَىْءٌ وَأَنْتَ الظَّاهِرُ فَلَيْسَ فَوْقَكَ شَىْءٌ وَأَنْتَ الْبَاطِنُ فَلَيْسَ دُونَكَ شَىْءٌ اقْضِ عَنَّا الدَّيْنَ وَأَغْنِنَا مِنَ الْفَقْرِ ‏"‏ ‏.‏\hadithno{3831}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"Fatimah came to the Prophet (saas) to ask him for a servant, and he said: 'I do not have anything to give you.' So she went back, but after that he came to her and said: 'Is what you asked for dearer to you, or something better than that?' 'Ali said to her: 'Say: something better than that.' So she said it. He said: 'Say: Allahumma Rabbas-samawatis-Sab'i wa Rabbal-'Arshil-'Azim, Rabbana wa Rabba Kulli shay'in, munzil at-Tawrati wal-Injili wal-Qur'anil-'Azim. Antal-Awwalu fa laysa qablaka shay', wa Antal-Akiru fa laysa ba'daka shay', Antaz-Zahiru fa laysa fawqaka shay', wa Antal-Batinu fa laysa dunaka shay', Iqdi 'annad-daina wa aghnina minal-faqr (O Allah, Lord of the seven heavens and Lord of the Mighty Throne, Our Lord, and the Lord of Everything, Revealer of the Tawrah, the Injil and the Magnificent Qur'an. You are the First and there is nothing after You; You are the Last and there is nothing after You. You are the Most High, and there is nothing above You, and You are the Most Near and there is nothing nearer than You. Settle our debts and make us free of want)}}
\hadithdefcmd{ibnmajah}{3832}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْهُدَى وَالتُّقَى وَالْعَفَافَ وَالْغِنَى ‏"‏ ‏.‏\hadithno{3832}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah that :the Prophet (saas) used to say: "Allahumma inni as'alukal-huda wat-tuqa wal-'afaf wal-ghina (O Allah, I ask You for guidance, piety, chastity and affluence)}}
\hadithdefcmd{ibnmajah}{3833}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ مُحَمَّدِ بْنِ ثَابِتٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ اللَّهُمَّ انْفَعْنِي بِمَا عَلَّمْتَنِي وَعَلِّمْنِي مَا يَنْفَعُنِي وَزِدْنِي عِلْمًا وَالْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ وَأَعُوذُ بِاللَّهِ مِنْ عَذَابِ النَّارِ ‏"‏ ‏.‏\hadithno{3833}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (saas) used to say: 'Allahummanfa'ni bima 'allamtani, wa 'allimni ma yanfa'uni, wa zidni 'ilman, wal-hamdu lillahi 'ala kulli hal, wa a'udhu billahi min 'adhabin-nar (O Allah, benefit me by that which You have taught me, and teach me that which will benefit me, and increase me in knowledge. Praise is to Allah in all situations, and I seek refuge with Allah from the torment of the Fire)}}
\hadithdefcmd{ibnmajah}{3834}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُكْثِرُ أَنْ يَقُولَ ‏"‏ اللَّهُمَّ ثَبِّتْ قَلْبِي عَلَى دِينِكَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ تَخَافُ عَلَيْنَا وَقَدْ آمَنَّا بِكَ وَصَدَّقْنَاكَ بِمَا جِئْتَ بِهِ فَقَالَ ‏"‏ إِنَّ الْقُلُوبَ بَيْنَ إِصْبَعَيْنِ مِنْ أَصَابِعِ الرَّحْمَنِ عَزَّ وَجَلَّ يُقَلِّبُهَا ‏"‏ ‏.‏ وَأَشَارَ الأَعْمَشُ بِإِصْبَعَيْهِ ‏.‏\hadithno{3834}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (saas) often used to say: 'Allahumma thabbit qalbi 'ala dinika [O Allah, make my heart steadfast in (adhering to) Your religion].' A man said: 'O Messenger of Allah! Do you fear for us when we have believed in you and in (the Message) that you have brought?' He said: 'Hearts are between two of the fingers of the Most Merciful, and He controls them.'" (Hasan)Al-A'mash (one of the narrators) indicated with his fingers}}
\hadithdefcmd{ibnmajah}{3835}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، ‏.‏ أَنَّهُ قَالَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي ‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَثِيرًا وَلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ فَاغْفِرْ لِي مَغْفِرَةً مِنْ عِنْدِكَ وَارْحَمْنِي إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏ ‏.‏\hadithno{3835}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Bakr Siddiq that :he said to the Messenger of Allah (saas): "Teach me a supplication which I can say during my prayer." He said: "Say: Allahumma inni zalamtu nafsi zulman kathiran wa la yaghfirudh-dhunub illa Anta, faghfirli maghfiratan min 'indika warhamni, innaka Antal-Ghafurur-Rahim (O Allah, I have wronged myself greatly and no one forgives sins but You, so grant me forgiveness from You and have mercy on me, for You are the Oft-Forgiving, Most Merciful)}}
\hadithdefcmd{ibnmajah}{3836}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ أَبِي مَرْزُوقٍ، عَنْ أَبِي الْعَدَبَّسِ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ مُتَّكِئٌ عَلَى عَصًا فَلَمَّا رَأَيْنَاهُ قُمْنَا فَقَالَ ‏"‏ لاَ تَفْعَلُوا كَمَا يَفْعَلُ أَهْلُ فَارِسَ بِعُظَمَائِهَا ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ لَوْ دَعَوْتَ اللَّهَ لَنَا ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لَنَا وَارْحَمْنَا وَارْضَ عَنَّا وَتَقَبَّلْ مِنَّا وَأَدْخِلْنَا الْجَنَّةَ وَنَجِّنَا مِنَ النَّارِ وَأَصْلِحْ لَنَا شَأْنَنَا كُلَّهُ ‏"‏ ‏.‏ قَالَ فَكَأَنَّمَا أَحْبَبْنَا أَنْ يَزِيدَنَا فَقَالَ ‏"‏ أَوَلَيْسَ قَدْ جَمَعْتُ لَكُمُ الأَمْرَ ‏"‏ ‏.‏\hadithno{3836}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah Al Bahili said:"The Messenger of Allah (saas) came out to us, leaning on a stick, and when we saw him we stood up. He said: 'Do not do what the Persians do for their leaders.' We said: 'O Messenger of Allah, why don't you pray to Allah for us?' He said: 'Allahummaghfirlana, warhamna, warda 'anna, wa taqabbal minna, wa adkhilnal-jannah, wa najjina minan-nar, wa aslih lana sha'nana kullah. [O Allah, forgive us and have mercy on us, be pleased with us and accept (our good deeds) from us, admit us to Paradise and save us from Hell, and rectify all our affairs].' It was as if we wanted him to say more, but he said: 'Have I not summed everything for you?}}
\hadithdefcmd{ibnmajah}{3837}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَخِيهِ، عَبَّادِ بْنِ أَبِي سَعِيدٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الأَرْبَعِ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَمِنْ دُعَاءٍ لاَ يُسْمَعُ ‏"‏ ‏.‏\hadithno{3837}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah told that the Messenger of Allah (saas) said:'Allahumma! Inni a'udhu bika minal-arba': min 'ilmin la yanfa'u, wa min qalbin la yakhsha'u, wa min nafsin la tashba'u, wa min du'a'in la yusma' [O Allah, I seek refuge with You from four things: From knowledge that is of no benefit, from a heart that does not fear (You), from a soul that is never satisfied, and from a supplication that is not heard}}
\hadithdefcmd{ibnmajah}{3838}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ النَّارِ وَعَذَابِ النَّارِ وَمِنْ فِتْنَةِ الْقَبْرِ وَعَذَابِ الْقَبْرِ وَمِنْ شَرِّ فِتْنَةِ الْغِنَى وَشَرِّ فِتْنَةِ الْفَقْرِ وَمِنْ شَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ وَنَقِّ قَلْبِي مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ وَبَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْمَأْثَمِ وَالْمَغْرَمِ ‏"‏ ‏.‏\hadithno{3838}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the :Prophet (saas) would supplicate with these words: "Allahumma inni a'udhu bika min fitnatin-nari wa 'adhabin-nar, wa min fitnatil-qabri wa 'adhabil-qabr, wa min sharri fitnatil-ghina wa min sharri fitnatil-faqr, wa min sharri fitnatil-masihid-dajjal. Allahumma aghsil khatayaya bima'ith-thalfi wal-barad, wa naqqi qalbi minal-khataya kama naqqaytath-thawbal-abyad minad-danas. Wa ba'id bayni wa bayna khatayaya kama ba'adta baynal-mashriqi wal-maghrib. Allahumma inni a'udhu bika minal-kasali wal-harami wal-ma'thami wal-maghrami (O Allah, I seek refuge with You from the tribulation of the Fire and the torment of the Fire, and from the tribulation of the grave, and from the evil of the tribulation of richness and the evil of the tribulation of poverty, and from the evil of the trial of the False Christ. O Allah! Wash away my sins with the water of snow and hail, and cleanse my heart from sin as a white garment is cleansed from filth, and put a great distance between me and my sins, as great as the distance You have made between the east and the west. O Allah! I seek refuge with You from laziness and old age, and from sins and debt)}}
\hadithdefcmd{ibnmajah}{3839}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنْ هِلاَلٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ دُعَاءٍ، كَانَ يَدْعُو بِهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{3839}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Farwah bin Nawfal said:"I asked 'Aishah about a supplication that the Messenger of Allah (saas) used to say. She said that he used to say: 'Allahumma inni a'udhu bika min sharri ma 'amiltu, wa min sharri ma lam a'mal (O Allah, I seek refuge with You from the evil of that which I have done and the evil of that which I have not done)}}
\hadithdefcmd{ibnmajah}{3840}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا بَكْرُ بْنُ سُلَيْمٍ، حَدَّثَنِي حُمَيْدٌ الْخَرَّاطُ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُعَلِّمُنَا هَذَا الدُّعَاءَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{3840}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (saas) used to teach us this supplication just as he would teach us a Surah from the Qur'an: 'Allahumma inni a'udhu bika min 'adhabi jahannam, wa a'udhu bika min 'adhabil-qabr, wa a'udhu bika min fitnatil-masihil-dajjal, wa a'udhu bika min fitnatil-mahya wal-mamat (O Allah, I seek refuge with You from the torment of Hell, and I seek refuge with You from the torment of the grave, and I see refuge with you from the tribulation of False Christ, and I seek refuge with You from the trials of life and death)}}
\hadithdefcmd{ibnmajah}{3841}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ لَيْلَةٍ مِنْ فِرَاشِهِ فَالْتَمَسْتُهُ فَوَقَعَتْ يَدِي عَلَى بَطْنِ قَدَمَيْهِ وَهُوَ فِي الْمَسْجِدِ وَهُمَا مَنْصُوبَتَانِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَبِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏\hadithno{3841}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I noticed that the Messenger of Allah (saas) was missing from his bed one night, so I went looking for him, and my hand touched the soles of his feet; he was in the Masjid with his feet upright (prostrating), and he was saying: 'Allahumma inni a'udhu biridaka min sakhatika wa bimu'afatika 'an 'uqubatika, wa a'udhu bika minka, la uhsi thana'an 'alayka, Anta kama athnayta 'ala nafsika (O Allah, I seek refuge in Your pleasure from Your wrath, and in Your forgiveness from Your punishment. I seek refuge in You from You. I cannot praise You enough; You are as You have praised Yourself)}}
\hadithdefcmd{ibnmajah}{3842}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، عَنِ الأَوْزَاعِيِّ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنْ جَعْفَرِ بْنِ عِيَاضٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَعَوَّذُوا بِاللَّهِ مِنَ الْفَقْرِ وَالْقِلَّةِ وَالذِّلَّةِ وَأَنْ تَظْلِمَ أَوْ تُظْلَمَ ‏"‏ ‏.‏\hadithno{3842}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said: "Seek refuge with Allah from poverty, insufficiency and humiliation, and from wronging (others) and being wronged}}
\hadithdefcmd{ibnmajah}{3843}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَلُوا اللَّهَ عِلْمًا نَافِعًا وَتَعَوَّذُوا بِاللَّهِ مِنْ عِلْمٍ لاَ يَنْفَعُ ‏"‏ ‏.‏\hadithno{3843}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir that :the Messenger of Allah said: "Ask Allah for beneficial knowledge and seek refuge with Allah from knowledge that is of no benefit}}
\hadithdefcmd{ibnmajah}{3844}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَتَعَوَّذُ مِنَ الْجُبْنِ وَالْبُخْلِ وَأَرْذَلِ الْعُمُرِ وَعَذَابِ الْقَبْرِ وَفِتْنَةِ الصَّدْرِ ‏.‏ قَالَ وَكِيعٌ يَعْنِي الرَّجُلَ يَمُوتُ عَلَى فِتْنَةٍ لاَ يَسْتَغْفِرُ اللَّهَ مِنْهَا ‏.‏\hadithno{3844}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Umar that the :Prophet saas used to seek refuge with Allah from cowardice, miserliness, old age, the torment of the grave and the tribulation of the heart. (Da'if)(One of the narrators) Waki' said: "Meaning when a man dies in a state of tribulation (Fitnah) and does not ask Allah to forgive him}}
\hadithdefcmd{ibnmajah}{3845}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا أَبُو مَالِكٍ، سَعْدُ بْنُ طَارِقٍ عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَقَدْ أَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ أَقُولُ حِينَ أَسْأَلُ رَبِّي قَالَ ‏"‏ قُلِ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَعَافِنِي وَارْزُقْنِي ‏"‏ ‏.‏ وَجَمَعَ أَصَابِعَهُ الأَرْبَعَ إِلاَّ الإِبْهَامَ ‏"‏ فَإِنَّ هَؤُلاَءِ يَجْمَعْنَ لَكَ دِينَكَ وَدُنْيَاكَ ‏"‏ ‏.‏\hadithno{3845}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Malik, Sa'd Bin Tariq, narrated from his father that :when a man had come to the Messenger of Allah (saas), he heard him say: "O Messenger of Allah, what should I say when I ask of Allah?" He said: "Say: Allahumma-ghfirli warhamni wa 'afini warzuqni (O Allah, forgive me, have mercy on me, keep me safe and sound and grant me provision)," and he held up his four fingers apart from the thumb and said: "These combine your religious and worldly affairs}}
\hadithdefcmd{ibnmajah}{3846}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنِي جَبْرُ بْنُ حَبِيبٍ، عَنْ أُمِّ كُلْثُومٍ بِنْتِ أَبِي بَكْرٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَّمَهَا هَذَا الدُّعَاءَ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنَ الْخَيْرِ كُلِّهِ عَاجِلِهِ وَآجِلِهِ مَا عَلِمْتُ مِنْهُ وَمَا لَمْ أَعْلَمْ وَأَعُوذُ بِكَ مِنَ الشَّرِّ كُلِّهِ عَاجِلِهِ وَآجِلِهِ مَا عَلِمْتُ مِنْهُ وَمَا لَمْ أَعْلَمْ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ خَيْرِ مَا سَأَلَكَ عَبْدُكَ وَنَبِيُّكَ وَأَعُوذُ بِكَ مِنْ شَرِّ مَا عَاذَ بِهِ عَبْدُكَ وَنَبِيُّكَ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْجَنَّةَ وَمَا قَرَّبَ إِلَيْهَا مِنْ قَوْلٍ أَوْ عَمَلٍ وَأَعُوذُ بِكَ مِنَ النَّارِ وَمَا قَرَّبَ إِلَيْهَا مِنْ قَوْلٍ أَوْ عَمَلٍ وَأَسْأَلُكَ أَنْ تَجْعَلَ كُلَّ قَضَاءٍ قَضَيْتَهُ لِي خَيْرًا ‏"‏ ‏.‏\hadithno{3846}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that :the Messenger of Allah (saas) taught her this supplication: "Allahumma inni as'aluka minal-khayri kullihi, 'ajilihi wa ajilihi, ma 'alimtu minhu wa ma la a'lam. Wa a'udhu bika minash-sharri kullihi, 'ajilihi wa ajilihi, ma 'alimtu minhu wa ma la a'lam. Allahumma inni as'aluka min khayri ma sa'alaka 'abduka wa nabiyyuka, wa a'udhu bika min sharri ma 'adha bihi 'abduka wa nabiyyuka. Allahumma inni as'alukal-jannatah wa ma qarrab ilayha min qawlin aw 'amalin, wa a'udhu bika minan-nari wa ma qarraba ilayha min qawlin aw 'amalin, wa as'aluka an taj'al kulla qada'in qadaytahuli khayran (O Allah, I ask You for all that is good, in this world and in the Hereafter, what I know and what I do not know. O Allah, I seek refuge with You from all evil, in this world and in the Hereafter, what I know and what I do not know. O Allah, I ask You for the good that Your slave and Prophet has asked You for, and I seek refuge with You from the evil from which Your slave and Prophet sought refuge. O Allah, I ask You for Paradise and for that which brings one closer to it, in word and deed, and I seek refuge in You from Hell and from that which brings one closer to it, in word and deed. And I ask You to make every decree that You decree concerning me good)}}
\hadithdefcmd{ibnmajah}{3847}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى الْقَطَّانُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِرَجُلٍ ‏"‏ مَا تَقُولُ فِي الصَّلاَةِ ‏"‏ ‏.‏ قَالَ أَتَشَهَّدُ ثُمَّ أَسْأَلُ اللَّهَ الْجَنَّةَ وَأَعُوذُ بِهِ مِنَ النَّارِ أَمَا وَاللَّهِ مَا أُحْسِنُ دَنْدَنَتَكَ وَلاَ دَنْدَنَةَ مُعَاذٍ ‏.‏ قَالَ ‏"‏ حَوْلَهُمَا نُدَنْدِنُ ‏"‏ ‏.‏\hadithno{3847}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said to a man: "What do you say during your prayer?" He said: "I recite the Tashah-hud then I ask for Allah for Paradise and see refuge with Him from Hell, but by Allah I do not understand your whispering or the whispering of Mu'adh." He said: "It is concerning them (Paradise and Hell) that we are whispering}}
\hadithdefcmd{ibnmajah}{3848}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنِي سَلَمَةُ بْنُ وَرْدَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الدُّعَاءِ أَفْضَلُ قَالَ ‏"‏ سَلْ رَبَّكَ الْعَفْوَ وَالْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ فِي الْيَوْمِ الثَّانِي فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الدُّعَاءِ أَفْضَلُ قَالَ ‏"‏ سَلْ رَبَّكَ الْعَفْوَ وَالْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ فِي الْيَوْمِ الثَّالِثِ فَقَالَ يَا نَبِيَّ اللَّهِ أَىُّ الدُّعَاءِ أَفْضَلُ قَالَ ‏"‏ سَلْ رَبَّكَ الْعَفْوَ وَالَعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ فَإِذَا أُعْطِيتَ الْعَفْوَ وَالْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ فَقَدْ أَفْلَحْتَ ‏"‏ ‏.‏\hadithno{3848}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"A man come to the Prophet (saas) and said: 'O Messenger of Allah, what supplication is best?' He said: 'Ask your Lord for forgiveness and to be kept safe and sound in this world and in the Hereafter.' Then (the man) came the next day and said: 'O Messenger of Allah, what supplication is best?' He said: 'Ask your Lord for forgiveness and to be kept safe and sound in this world and in the Hereafter.' Then (the man) came the third day and said: 'O Prophet of Allah, what supplication is best?' He said: 'Ask your Lord for forgiveness and to be kept safe and sound in this world and in the Hereafter, for if you are forgiven and kept safe and sound in this world and the Hereafter, you will have succeeded}}
\hadithdefcmd{ibnmajah}{3849}{حَدَّثَنَا أَبُو بَكْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا عُبَيْدُ بْنُ سَعِيدٍ، قَالَ سَمِعْتُ شُعْبَةَ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، قَالَ سَمِعْتُ سُلَيْمَ بْنَ عَامِرٍ، يُحَدِّثُ عَنْ أَوْسَطَ بْنِ إِسْمَاعِيلَ الْبَجَلِيِّ، أَنَّهُ سَمِعَ أَبَا بَكْرٍ، حِينَ قُبِضَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَقُولُ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي مَقَامِي هَذَا عَامَ الأَوَّلِ ثُمَّ بَكَى أَبُو بَكْرٍ ثُمَّ قَالَ ‏ "‏ عَلَيْكُمْ بِالصِّدْقِ فَإِنَّهُ مَعَ الْبِرِّ وَهُمَا فِي الْجَنَّةِ وَإِيَّاكُمْ وَالْكَذِبَ فَإِنَّهُ مَعَ الْفُجُورِ وَهُمَا فِي النَّارِ وَسَلُوا اللَّهَ الْمُعَافَاةَ فَإِنَّهُ لَمْ يُؤْتَ أَحَدٌ بَعْدَ الْيَقِينِ خَيْرًا مِنَ الْمُعَافَاةِ وَلاَ تَحَاسَدُوا وَلاَ تَبَاغَضُوا وَلاَ تَقَاطَعُوا وَلاَ تَدَابَرُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا ‏"‏ ‏.‏\hadithno{3849}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Awsat (bin Isma'il) Al-Bajali that :he heard Abu Bakr, when the Prophet (saas) had passed away, saying: "The Messenger of Allah (saas) stood in this place where I am standing, last year." Then Abu Bakr wept, then he said: "You must adhere to the truth, for with it comes righteousness and they both lead to Paradise. And you must beware of lying for with it comes immorality, and they both lead to Hell. Ask Allah for Al-Mu'afah, for no one is given anything after certainty that is better than Mu'afah. Do not envy one another, do not hate one another, do not sever ties with one another, do not turn your backs on one another and be, O slaves of Allah, brothers}}
\hadithdefcmd{ibnmajah}{3850}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ كَهْمَسِ بْنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ وَافَقْتُ لَيْلَةَ الْقَدْرِ مَا أَدْعُو قَالَ ‏ "‏ تَقُولِينَ اللَّهُمَّ إِنَّكَ عَفُوٌّ تُحِبُّ الْعَفْوَ فَاعْفُ عَنِّي ‏"‏ ‏.‏\hadithno{3850}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that she said:"O Messenger of Allah, what do you think I should say in my supplication, if I come upon Laylatul-Qadr?" He said: "Say: 'Allahumma innaka 'afuwwun tuhibbul-'afwa, fa'fu 'anni (O Allah, You are Forgiving and love forgiveness, so forgive me)}}
\hadithdefcmd{ibnmajah}{3851}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، صَاحِبِ الدَّسْتَوَائِيِّ عَنْ قَتَادَةَ، عَنِ الْعَلاَءِ بْنِ زِيَادٍ الْعَدَوِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ دَعْوَةٍ يَدْعُو بِهَا الْعَبْدُ أَفْضَلَ مِنَ - اللَّهُمَّ إِنِّي أَسْأَلُكَ الْمُعَافَاةَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏\hadithno{3851}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (saas) said: 'There is no supplication that a person can say that is better than: Allahumma inni as'aluka al-mu'afah fid-dunya wal-akhirah (O Allah, I ask You for Al-Mu'afah in this world and in the Hereafter)}}
\hadithdefcmd{ibnmajah}{3852}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَرْحَمُنَا اللَّهُ وَأَخَا عَادٍ ‏"‏ ‏.‏\hadithno{3852}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that :the Messenger of Allah (saas) said: "May Allah have mercy on us and on our brother of 'Ad." (i.e., Prophet Hud alay-salaam)}}
\hadithdefcmd{ibnmajah}{3853}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ ‏"‏ ‏.‏ قِيلَ وَكَيْفَ يَعْجَلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ يَقُولُ قَدْ دَعَوْتُ اللَّهَ فَلَمْ يَسْتَجِبِ اللَّهُ لِي ‏"‏ ‏.‏\hadithno{3853}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said: "It is necessary that you do not become hasty." It was said: "What does being hasty mean, O Messenger of Allah?" He said: "When one says: 'I supplicated to Allah but Allah did not answer me}}
\hadithdefcmd{ibnmajah}{3854}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمُ اللَّهُمَّ اغْفِرْ لِي إِنْ شِئْتَ وَلْيَعْزِمْ فِي الْمَسْأَلَةِ فَإِنَّ اللَّهَ لاَ مُكْرِهَ لَهُ ‏"‏ ‏.‏\hadithno{3854}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the :Messenger of Allah (saas) said: "No one among you should say: "O Allah, forgive me if You will.' Let him be definite in his asking, and no one can compel Allah}}
\hadithdefcmd{ibnmajah}{3855}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي زِيَادٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اسْمُ اللَّهِ الأَعْظَمُ فِي هَاتَيْنِ الآيَتَيْنِ ‏\{وَإِلَهُكُمْ إِلَهٌ وَاحِدٌ لاَ إِلَهَ إِلاَّ هُوَ الرَّحْمَنُ الرَّحِيمُ\}‏ وَفَاتِحَةِ سُورَةِ آلِ عِمْرَانَ ‏"‏ ‏.‏\hadithno{3855}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Asma' bint Yazid that :the Messenger of Allah (saas) said: "The Greatest Name of Allah is in these two Verses: And your Ilah (God) is One Ilah (God - Allah), La Ilaha Illa Huwa (none has the right to be worshipped but He), the Most Gracious, the Most Merciful.' And at the beginning of Surah Al 'Imran}}
\hadithdefcmd{ibnmajah}{3856}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْعَلاَءِ، عَنِ الْقَاسِمِ، قَالَ اسْمُ اللَّهِ الأَعْظَمُ الَّذِي إِذَا دُعِيَ بِهِ أَجَابَ فِي سُوَرٍ ثَلاَثٍ الْبَقَرَةِ وَآلِ عِمْرَانَ وَطَهَ ‏.‏ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، قَالَ ذَكَرْتُ ذَلِكَ لِعِيسَى بْنِ مُوسَى فَحَدَّثَنِي أَنَّهُ، سَمِعَ غَيْلاَنَ بْنَ أَنَسٍ، يُحَدِّثُ عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{3856}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Qasim said:The Greatest Name of Allah, if He is called by which He will respond, is in three Surah: Al-Baqarah, Al 'Imran and Ta-Ha. (Hasan)Another chain for something similar from Al-Qasim, from Abu Umamah, from the Prophet (saas)}}
\hadithdefcmd{ibnmajah}{3857}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، أَنَّهُ سَمِعَهُ مِنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ سَمِعَ النَّبِيُّ ـ صلى الله عليه وسلم ـ رَجُلاً يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ بِأَنَّكَ أَنْتَ اللَّهُ الأَحَدُ الصَّمَدُ الَّذِي لَمْ يَلِدْ وَلَمْ يُولَدْ وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَقَدْ سَأَلَ اللَّهَ بِاسْمِهِ الأَعْظَمِ الَّذِي إِذَا سُئِلَ بِهِ أَعْطَى وَإِذَا دُعِيَ بِهِ أَجَابَ ‏"‏ ‏.‏\hadithno{3857}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that his father said:"The Prophet (saas) heard a man say: 'Allahumma! Inni as'aluka bi-annaka Antallahul-Ahadus-Samad, alladhi lam yalid wa lam yuwlud, wa lam yakun lahu kufuwan ahad (O Allah! I ask You by virtue of Your being Allah, the One, the Self-Sufficient Master, Who begets not nor was begotten, and there is none co-equal or comparable to Him).' The Messenger of Allah (saas) said: 'He has asked Allah by His Greatest Name, which if He is asked thereby He gives, and if He is called upon thereby He answers}}
\hadithdefcmd{ibnmajah}{3858}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبُو خُزَيْمَةَ، عَنْ أَنَسِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعَ النَّبِيُّ ـ صلى الله عليه وسلم ـ رَجُلاً يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ بِأَنَّ لَكَ الْحَمْدَ لاَ إِلَهَ إِلاَّ أَنْتَ وَحْدَكَ لاَ شَرِيكَ لَكَ الْمَنَّانُ بَدِيعُ السَّمَوَاتِ وَالأَرْضِ ذُو الْجَلاَلِ وَالإِكْرَامِ فَقَالَ ‏ "‏ لَقَدْ سَأَلَ اللَّهَ بِاسْمِهِ الأَعْظَمِ الَّذِي إِذَا سُئِلَ بِهِ أَعْطَى وَإِذَا دُعِيَ بِهِ أَجَابَ ‏"‏ ‏.‏\hadithno{3858}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Prophet (saas) heard a man say: 'Allahumma! Inni as'aluka bi-anna lakal-hamd. La ilaha illa Anta, wahdaka la sharika laka. Al-Mannan. Badi'us-samawati wal-ard. Dhul-jalali wal-ikram (O Allah! I ask You by virtue of the fact that all praise is due to You; none has the right to be worshiped but You alone, and You have no partner or associate, the Bestower, the Originator of the heavens and the earth, the Possessor of majesty and honor.' He (saas) said: 'He has asked Allah by His Greatest Name which, if He is asked thereby He gives and if He is called upon thereby He answers}}
\hadithdefcmd{ibnmajah}{3859}{حَدَّثَنَا أَبُو يُوسُفَ الصَّيْدَلاَنِيُّ، مُحَمَّدُ بْنُ أَحْمَدَ الرَّقِّيُّ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ الْفَزَارِيِّ، عَنْ أَبِي شَيْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ الْجُهَنِيِّ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ بِاسْمِكَ الطَّاهِرِ الطَّيِّبِ الْمُبَارَكِ الأَحَبِّ إِلَيْكَ الَّذِي إِذَا دُعِيتَ بِهِ أَجَبْتَ وَإِذَا سُئِلْتَ بِهِ أَعْطَيْتَ وَإِذَا اسْتُرْحِمْتَ بِهِ رَحِمْتَ وَإِذَا اسْتُفْرِجْتَ بِهِ فَرَّجْتَ ‏"‏ ‏.‏ قَالَتْ وَقَالَ ذَاتَ يَوْمٍ ‏"‏ يَا عَائِشَةُ هَلْ عَلِمْتِ أَنَّ اللَّهَ قَدْ دَلَّنِي عَلَى الاِسْمِ الَّذِي إِذَا دُعِيَ بِهِ أَجَابَ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي فَعَلِّمْنِيهِ ‏.‏ قَالَ ‏"‏ إِنَّهُ لاَ يَنْبَغِي لَكِ يَا عَائِشَةُ ‏"‏ ‏.‏ قَالَتْ فَتَنَحَّيْتُ وَجَلَسْتُ سَاعَةً ثُمَّ قُمْتُ فَقَبَّلْتُ رَأْسَهُ ثُمَّ قُلْتُ يَا رَسُولَ اللَّهِ عَلِّمْنِيهِ ‏.‏ قَالَ ‏"‏ إِنَّهُ لاَ يَنْبَغِي لَكِ يَا عَائِشَةُ أَنْ أُعَلِّمَكِ إِنَّهُ لاَ يَنْبَغِي لَكِ أَنْ تَسْأَلِي بِهِ شَيْئًا مِنَ الدُّنْيَا ‏"‏ ‏.‏ قَالَتْ فَقُمْتُ فَتَوَضَّأْتُ ثُمَّ صَلَّيْتُ رَكْعَتَيْنِ ثُمَّ قُلْتُ اللَّهُمَّ إِنِّي أَدْعُوكَ اللَّهَ وَأَدْعُوكَ الرَّحْمَنَ وَأَدْعُوكَ الْبَرَّ الرَّحِيمَ وَأَدْعُوكَ بِأَسْمَائِكَ الْحُسْنَى كُلِّهَا مَا عَلِمْتُ مِنْهَا وَمَا لَمْ أَعْلَمْ أَنْ تَغْفِرَ لِي وَتَرْحَمَنِي ‏.‏ قَالَتْ فَاسْتَضْحَكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ قَالَ ‏"‏ إِنَّهُ لَفِي الأَسْمَاءِ الَّتِي دَعَوْتِ بِهَا ‏"‏ ‏.‏\hadithno{3859}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"I heard the Messenger of Allah (saas) say: 'Allahumma! Inni asa'luka bismikat-tahirit-tayyibil-mubarak al-ahabbi ilaika, alladhi idha du'ita bihi ajabta, wa idha su'ilta bihi a'taita, wa idhasturhimta bihi rahimta, wa idhastufrijta bihi farrajta (O Allah! I ask You by Your pure, good and blessed Name which is most beloved by You, which if You are called thereby You answer, and if You as asked thereby You give, if You are asked for mercy thereby You bestow mercy, and if You are asked for relief (from distress) thereby You grant relief.'"She said: "He said one day: 'O 'Aishah, do you know that Allah has told me the Name which, if He is called thereby, He responds?' I said: 'O Messenger of Allah, may my father and mother be ransomed for you! Teach it to me.' He said: 'You should not learn it, O 'Aishah.' So I moved aside and sat for a while, then I got up and kissed his head, then I said: 'O Messenger of Allah, teach it to me.' He said: 'You should not learn it, O 'Aishah, and I should not teach it to you, for you should not ask for any worldly things thereby.'" She said: "So I got up and performed ablution, then I prayed two Rak'ah, then I said: 'O Allah, I call upon Allah, and I call upon You, Ar-Rahman (the Most Gracious), and I call upon You, Al-Barr Ar-Rahim (The Most Kind, the Most Merciful), and I call upon You by all Your beautiful Names, those that I know and those that I do not know, (asking) that You forgive me and have mercy on me.' The Messenger of Allah (saas) smiled, then he said: 'It is among the names by which you called upon (Allah)}}
\hadithdefcmd{ibnmajah}{3860}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِلَّهِ تِسْعَةً وَتِسْعِينَ اسْمًا مِائَةً إِلاَّ وَاحِدًا مَنْ أَحْصَاهَا دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3860}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said: "Allah has ninety-nine Names, one hundred less one. Whoever counts them will enter Paradise}}
\hadithdefcmd{ibnmajah}{3861}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدٍ الصَّنْعَانِيُّ، حَدَّثَنَا أَبُو الْمُنْذِرِ، زُهَيْرُ بْنُ مُحَمَّدٍ التَّمِيمِيُّ حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ الأَعْرَجُ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ لِلَّهِ تِسْعَةً وَتِسْعِينَ اسْمًا مِائَةً إِلاَّ وَاحِدًا إِنَّهُ وِتْرٌ يُحِبُّ الْوِتْرَ مَنْ حَفِظَهَا دَخَلَ الْجَنَّةَ وَهِيَ اللَّهُ الْوَاحِدُ الصَّمَدُ الأَوَّلُ الآخِرُ الظَّاهِرُ الْبَاطِنُ الْخَالِقُ الْبَارِئُ الْمُصَوِّرُ الْمَلِكُ الْحَقُّ السَّلاَمُ الْمُؤْمِنُ الْمُهَيْمِنُ الْعَزِيزُ الْجَبَّارُ الْمُتَكَبِّرُ الرَّحْمَنُ الرَّحِيمُ اللَّطِيفُ الْخَبِيرُ السَّمِيعُ الْبَصِيرُ الْعَلِيمُ الْعَظِيمُ الْبَارُّ الْمُتَعَالِ الْجَلِيلُ الْجَمِيلُ الْحَىُّ الْقَيُّومُ الْقَادِرُ الْقَاهِرُ الْعَلِيُّ الْحَكِيمُ الْقَرِيبُ الْمُجِيبُ الْغَنِيُّ الْوَهَّابُ الْوَدُودُ الشَّكُورُ الْمَاجِدُ الْوَاجِدُ الْوَالِي الرَّاشِدُ الْعَفُوُّ الْغَفُورُ الْحَلِيمُ الْكَرِيمُ التَّوَّابُ الرَّبُّ الْمَجِيدُ الْوَلِيُّ الشَّهِيدُ الْمُبِينُ الْبُرْهَانُ الرَّءُوفُ الرَّحِيمُ الْمُبْدِئُ الْمُعِيدُ الْبَاعِثُ الْوَارِثُ الْقَوِيُّ الشَّدِيدُ الضَّارُّ النَّافِعُ الْبَاقِي الْوَاقِي الْخَافِضُ الرَّافِعُ الْقَابِضُ الْبَاسِطُ الْمُعِزُّ الْمُذِلُّ الْمُقْسِطُ الرَّزَّاقُ ذُو الْقُوَّةِ الْمَتِينُ الْقَائِمُ الدَّائِمُ الْحَافِظُ الْوَكِيلُ الْفَاطِرُ السَّامِعُ الْمُعْطِي الْمُحْيِي الْمُمِيتُ الْمَانِعُ الْجَامِعُ الْهَادِي الْكَافِي الأَبَدُ الْعَالِمُ الصَّادِقُ النُّورُ الْمُنِيرُ التَّامُّ الْقَدِيمُ الْوِتْرُ الأَحَدُ الصَّمَدُ الَّذِي لَمْ يَلِدْ وَلَمْ يُولَدْ وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ فَبَلَغَنَا عَنْ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ أَنَّ أَوَّلَهَا يُفْتَحُ بِقَوْلِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ بِيَدِهِ الْخَيْرُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ لاَ إِلَهَ إِلاَّ اللَّهُ لَهُ الأَسْمَاءُ الْحُسْنَى ‏.‏\hadithno{3861}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said: "Allah has ninety-nine names, one hundred less one, for He is One and loves the odd (numbered). Whoever learns them will enter Paradise. They are: Allah, Al-Wahid (the One), As-Samad (the Self-Sufficient Master who all creatures need, He neither eats nor drinks), Al-Awwal (the First), Al-Akhir (the Last), Az-Zahir (the Most High), Al-Batin (the Most Near), Al-Khaliq (the Creator), Al-Bari (the Inventor of all things), Al-Musawwir (the Bestower of forms), Al-Malik (the King), Al-Haqq (the Truth), As-Salam (the One free from all defects), Al-Mu'min (the Giver of security), Al-Muhaymin (the Watcher over His creatures), Al-'Aziz (the All-Mighty), Al-Jabbar (the Compeller), Al-Mutakabbir (the Supreme), Ar-Rahman (the Most Gracious), Ar-Rahim (the Most Merciful), Al-Latif (the Most Subtle and Courteous), Al-Khabir (the Aware), As-Sami' (the Hearing), Al-Basir (the Seeing), Al-'Alim (the All-Knowing), Al-'Azim (the Most Great), Al-Barr (the Source of goodness), Al-Muta'al (the Most Exalted), Al-Jalil (the Sublime One), Al-Jamil (the Beautiful), Al-Hayy (the Ever-Living), Al-Qayyum (the One Who sustains and protects all that exists), Al-Qadir (the Able), Al-Qahir (the Irrestible), Al-'Ali (the Exalted), Al-Hakim (the Most Wise), Al-Qarib (the Ever-Near), Al-Mujib (the Responsive), Al-Ghani (the Self-Sufficient), Al-Wahhab (the Bestower), Al-Wadud (the Loving), Ash-Shakur (the Appreciative), Al-Majid (the Most Gentle), Al-Wajid (the Patron), Al-Wali (the Governor), Al-Rashid (the Guide), Al-'Afuw (the Pardoner), Al-Ghafur (the Forgiver), Al-Halim (the Forbearing One), Al-Karim (the Most Generous), At-Tawwab (the Acceptor of Repentance), Ar-Rabb (the Lord and Cherisher), Al-Majid (the Most Glorious), Al-Wali (the Helper), Ash-Shahid (the Witness), Al-Mubin (the Manifest), Al-Burhan (the Proof), Ar-Ra'uf (the Compassionate), Ar-Rahim (the Most Merciful), Al-Mubdi' (the Originator), Al-Mu'id (the Restorer), Al-Ba'ith (the Resurrector), Al-Warith (the Supreme Inheritor), Al-Qawi (the All-Strong), Ash-Shadid (the Severe), Ad-Darr (the One Who harms), An-Nafi' (the One Who benefits), Al-Baqi' (the Everlasting), Al-Waqi (the Protector), Al-Khafid (the Humble), Ar-Rafi' (the Exalter), Al-Qabid (the Retainer), Al-Basit (the Expander), Al-Mu'izz (the Honorer), Al-Mudhill (the Humiliator), Al-Muqsit (the Equitable), Ar-Razzaq (the Providor), Dhul-Quwwah (the Powerful), Al-Matin (the Most Strong), Al-Qa'im (the Firm), Ad-Da'im (the Eternal), Al-Hafiz (the Guardian), Al-Wakil (the Trustee), Al-Fatir (the Originator of creation), As-Sami' (the Hearer), Al-Mu'ti (the Giver), Al-Muhyi (the Giver of life), Al-Mumit (the Giver of death), Al-Mani' (the Withholder), Al-Jami' (the Gatherer), Al-Hadi (the Guide), Al-Kafi (the Sufficient), Al-Abad (the Eternal), Al-'Alim (the Knower), As-Sadiq (the Truthful), An-Nur (the Light), Al-Munir (the Giver of light), At-Tamm (the Perfect), Al-Qadim (the Earlier), Al-Witr (the One), Al-Ahad (the Lone), As-Samad [(the Self-sufficient Master, Who all creatures need, (He neither eats no drinks)]. He begets not, nor was He begotten. And there is none co-equal or comparable unto him."(One of the narrators) Zuhair said: We heard from more than one of the scholars that the first of these (names) should begin after saying: La ilaha illallahu wahdahu la sharika lahu, lahul-mulku wa lahul-hamdu, bi yadihil-khair wa Huwa 'ala kulli shay-in Qadir, la ilaha illallahu lahul-asma'ul-husna [None has the right to be worshipped but Allah, with no partner or associate. His is the dominion and all praise is His. In His Hand is (all) goodness, and He is Able to do all things, none has the right to be worshipped but Allah, and His are the (Most) Beautiful Names}}
\hadithdefcmd{ibnmajah}{3862}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ السَّهْمِيُّ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي جَعْفَرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثُ دَعَوَاتٍ يُسْتَجَابُ لَهُنَّ لاَ شَكَّ فِيهِنَّ دَعْوَةُ الْمَظْلُومِ وَدَعْوَةُ الْمُسَافِرِ وَدَعْوَةُ الْوَالِدِ لِوَلَدِهِ ‏"‏ ‏.‏\hadithno{3862}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah that :the Messenger of Allah (saas) said: "There are three supplications that will undoubtedly be answered: the supplication of one who has been wronged; the supplication of the traveler; and the supplication of a father for his child}}
\hadithdefcmd{ibnmajah}{3863}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو سَلَمَةَ، حَدَّثَتْنَا حَبَابَةُ ابْنَةُ عَجْلاَنَ، عَنْ أُمِّهَا أُمِّ حَفْصٍ، عَنْ صَفِيَّةَ بِنْتِ جَرِيرٍ، عَنْ أُمِّ حَكِيمٍ بِنْتِ وَدَاعٍ الْخُزَاعِيَّةِ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ دُعَاءُ الْوَالِدِ يُفْضِي إِلَى الْحِجَابِ ‏"‏ ‏.‏\hadithno{3863}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Haim bint Wadda' Al-Khuza'iyyah said:"I heard the Messenger of Allah (saas) say: 'The supplication of a father reaches the Veil (i.e. the place of repentance)}}
\hadithdefcmd{ibnmajah}{3864}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَنْبَأَنَا سَعِيدٌ الْجُرَيْرِيُّ، عَنْ أَبِي نَعَامَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ مُغَفَّلٍ، سَمِعَ ابْنَهُ، يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْقَصْرَ الأَبْيَضَ عَنْ يَمِينِ الْجَنَّةِ، إِذَا دَخَلْتُهَا ‏.‏ فَقَالَ أَىْ بُنَىَّ سَلِ اللَّهَ الْجَنَّةَ وَعُذْ بِهِ مِنَ النَّارِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ سَيَكُونُ قَوْمٌ يَعْتَدُونَ فِي الدُّعَاءِ ‏"‏ ‏.‏\hadithno{3864}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Na'amah that :'Abdullah bin Mughaffal heard his son say: "O Allah, I ask You for the white palace on the right-hand side of Paradise, when I enter it." He said: "O my son, ask Allah for Paradise and seek refuge with Him from Hell, for I heard the Messenger of Allah (saas) say: 'There will be people who will transgress in supplication}}
\hadithdefcmd{ibnmajah}{3865}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ جَعْفَرِ بْنِ مَيْمُونٍ، عَنْ أَبِي عُثْمَانَ، عَنْ سَلْمَانَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ رَبَّكُمْ حَيِيٌّ كَرِيمٌ يَسْتَحْيِي مِنْ عَبْدِهِ أَنْ يَرْفَعَ إِلَيْهِ يَدَيْهِ فَيَرُدَّهُمَا صِفْرًا - أَوْ قَالَ خَائِبَتَيْنِ ‏"‏ ‏.‏\hadithno{3865}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salman that the :Prophet (saas) said: "Your Lord is Kind and Most Generous, and is too kind to let His slave, if he raises his hands to Him, bring them back empty," or he said "frustrated}}
\hadithdefcmd{ibnmajah}{3866}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَائِذُ بْنُ حَبِيبٍ، عَنْ صَالِحِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا دَعَوْتَ اللَّهَ فَادْعُ بِبُطُونِ كَفَّيْكَ وَلاَ تَدْعُ بِظُهُورِهِمَا فَإِذَا فَرَغْتَ فَامْسَحْ بِهِمَا وَجْهَكَ ‏"‏ ‏.‏\hadithno{3866}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that :the Messenger of Allah (saas) said: "When you supplicate to Allah, supplicate with your palms uppermost, not with the backs of your hands uppermost, and when you finish, wipe your face with them}}
\hadithdefcmd{ibnmajah}{3867}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي عَيَّاشٍ الزُّرَقِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ قَالَ حِينَ يُصْبِحُ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ - كَانَ لَهُ عَدْلَ رَقَبَةٍ مِنْ وَلَدِ إِسْمَاعِيلَ وَحُطَّ عَنْهُ عَشْرُ خَطِيئَاتٍ وَرُفِعَ لَهُ عَشْرُ دَرَجَاتٍ وَكَانَ فِي حِرْزٍ مِنَ الشَّيْطَانِ حَتَّى يُمْسِيَ وَإِذَا أَمْسَى فَمِثْلُ ذَلِكَ حَتَّى يُصْبِحَ ‏"‏ ‏.‏ قَالَ فَرَأَى رَجُلٌ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِيمَا يَرَى النَّائِمُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبَا عَيَّاشٍ يَرْوِي عَنْكَ كَذَا وَكَذَا ‏.‏ فَقَالَ ‏"‏ صَدَقَ أَبُو عَيَّاشٍ ‏"‏ ‏.‏\hadithno{3867}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu 'Ayyash Az-Zuraqi that :the Messenger of Allah (saas) said: "Whoever says in the morning: 'La illaha illalahu wahdahu la sharika lahu, lahul-mulku wa lahul-hamdu, wa Huwa 'ala kulli shay'in Qadir (None has the right to be worshipped but Allah alone, with no partner or associate. His is the dominion and all praise is to Him, and He is Able to all things)' - he will have (a reward) equal to freeing a slave among the sons of Isma'il, ten bad deeds will be erased from (his record), he will be raised (in status) ten degrees, and he will have protection against Satan until evening comes. When evening comes, (if he says likewise) he will have the same until morning comes.'" (Sahih)He (one of the narrators) said: "A man saw the Messenger of Allah (saas) in a dream and said: 'O Messenger of Allah, Abu 'Ayyash narrated such and such from you.' He said: 'Abu 'Ayyash spoke the truth}}
\hadithdefcmd{ibnmajah}{3868}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَصْبَحْتُمْ فَقُولُوا اللَّهُمَّ بِكَ أَصْبَحْنَا وَبِكَ أَمْسَيْنَا وَبِكَ نَحْيَى وَبِكَ نَمُوتُ وَإِذَا أَمْسَيْتُمْ فَقُولُوا اللَّهُمَّ بِكَ أَمْسَيْنَا وَبِكَ أَصْبَحْنَا وَبِكَ نَحْيَى وَبِكَ نَمُوتُ وَإِلَيْكَ الْمَصِيرُ ‏"‏ ‏.‏\hadithno{3868}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said: "In the morning say: 'Allahumma bika asbahna, wa bika amsayna, wa bika nahya, wa bika namut (O Allah, by Your leave we have reached the morning and by Your leave we reach the evening, and by Your leave we live and by Your leave we die). And when evening comes, say: Allahumma bika amsayna, wa bika asbahna, wa bika nahya, wa bika namut, wa ilaykal-masir (O Allah, by Your leave we have reached the evening and by Your leave we reach the morning, and by Your leave we live and by Your leave we die, and unto You is our return)}}
\hadithdefcmd{ibnmajah}{3869}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ أَبَانَ بْنِ عُثْمَانَ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ يَقُولُ فِي صَبَاحِ كُلِّ يَوْمٍ وَمَسَاءِ كَلِّ لَيْلَةٍ بِسْمِ اللَّهِ الَّذِي لاَ يَضُرُّ مَعَ اسْمِهِ شَىْءٌ فِي الأَرْضِ وَلاَ فِي السَّمَاءِ وَهُوَ السَّمِيعُ الْعَلِيمُ ثَلاَثَ مَرَّاتٍ - فَيَضُرَّهُ شَىْءٌ ‏"‏ ‏.‏ قَالَ وَكَانَ أَبَانُ قَدْ أَصَابَهُ طَرَفٌ مِنَ الْفَالِجِ فَجَعَلَ الرَّجُلُ يَنْظُرُ إِلَيْهِ فَقَالَ لَهُ أَبَانُ مَا تَنْظُرُ إِلَىَّ أَمَا إِنَّ الْحَدِيثَ كَمَا قَدْ حَدَّثْتُكَ وَلَكِنِّي لَمْ أَقُلْهُ يَوْمَئِذٍ لِيُمْضِيَ اللَّهُ عَلَىَّ قَدَرَهُ ‏.‏\hadithno{3869}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Uthman bin 'Affan said:"I heard the Messenger of Allah (saas) say: "There is no person who says, in the morning and evening of every day: Bismillahil-ladhi la yadurru ma'a ismihi shay'un fil-ardi wa la fis-sama'i wa Huwas-Sami'ul-'Alim (In the name of Allah with Whose Name nothing on earth or in heaven harms, and He is the All-Seeing, All-Knowing), three times, and is then harmed by anything.'" (Hasan)He (one of the narrators) said: "Aban had been stricken with paralysis on one side of his body, and a man started looking at him. Aban said: 'Why are you looking at me? The Hadith is as I have narrated it to you, but I did not say it that day, so that the decree of Allah might be implemented}}
\hadithdefcmd{ibnmajah}{3870}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مِسْعَرٌ، حَدَّثَنَا أَبُو عَقِيلٍ، عَنْ سَابِقٍ، عَنْ أَبِي سَلاَّمٍ، خَادِمِ النَّبِيِّ ـ صلى الله عليه وسلم ـ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مِنْ مُسْلِمٍ أَوْ إِنْسَانٍ أَوْ عَبْدٍ يَقُولُ حِينَ يُمْسِي وَحِينَ يُصْبِحُ رَضِيتُ بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ نَبِيًّا - إِلاَّ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يُرْضِيَهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3870}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Salam, the servant of the Prophet (saas), that :the Prophet (saas) said: "There is no Muslim - or no person, or slave (of Allah) - who says, in the morning and evening: 'Radaytu billahi Rabban wa bil-Islami dinan wa bi Muhammadin nabiyyan (I am content with Allah as my Lord, Islam as my religion and Muhammad as my Prophet),' but he will have a promise from Allah to make him pleased on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{3871}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ الطَّنَافِسِيُّ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عُبَادَةُ بْنُ مُسْلِمٍ، حَدَّثَنَا جُبَيْرُ بْنُ أَبِي سُلَيْمَانَ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ لَمْ يَكُنْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَدَعُ هَؤُلاَءِ الدَّعَوَاتِ حِينَ يُمْسِي وَحِينَ يُصْبِحُ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْعَفْوَ وَالْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْعَفْوَ وَالْعَافِيَةَ فِي دِينِي وَدُنْيَاىَ وَأَهْلِي وَمَالِي اللَّهُمَّ اسْتُرْ عَوْرَاتِي وَآمِنْ رَوْعَاتِي وَاحْفَظْنِي مِنْ بَيْنِ يَدَىَّ وَمِنْ خَلْفِي وَعَنْ يَمِينِي وَعَنْ شِمَالِي وَمِنْ فَوْقِي وَأَعُوذُ بِكَ أَنْ أُغْتَالَ مِنْ تَحْتِي ‏"‏ ‏.‏ قَالَ وَكِيعٌ يَعْنِي الْخَسْفَ ‏.‏\hadithno{3871}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (saas) never abandoned these supplications, every morning and evening: Allahumma inni as'alukal-'afwa wal-'afiyah fid-dunya wal-akhirah. Allahumma inni as'alukal-'afwa wal-'afiyah fi dini wa dunyaya wa ahli wa mali. Allahum-mastur 'awrati, wa amin raw'ati wahfazni min bayni yadayya, wa min khalfi, wa 'an yamini wa 'an shimali, wa min fawqi, wa 'audhu bika an ughtala min tahti (O Allah, I ask You for forgiveness and well-being in this world and in the Hereafter. O Allah, I ask You for forgiveness and well-being in my religious and my worldly affairs. O Allah, conceal my faults, calm my fears, and protect me from before me and behind me, from my right and my left, and from above me, and I seek refuge in You from being taken unaware from beneath me)." Waki' (one of the narrators, explaining) said: "Meaning Al-Khasf (disgrace)}}
\hadithdefcmd{ibnmajah}{3872}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُيَيْنَةَ، حَدَّثَنَا الْوَلِيدُ بْنُ ثَعْلَبَةَ، عَنْ عَبْدِ اللَّهِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اللَّهُمَّ أَنْتَ رَبِّي لاَ إِلَهَ إِلاَّ أَنْتَ خَلَقْتَنِي وَأَنَا عَبْدُكَ وَأَنَا عَلَى عَهْدِكَ وَوَعْدِكَ مَا اسْتَطَعْتُ أَعُوذُ بِكَ مِنْ شَرِّ مَا صَنَعْتُ أَبُوءُ بِنِعْمَتِكَ وَأَبُوءُ بِذَنْبِي فَاغْفِرْ لِي فَإِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ قَالَهَا فِي يَوْمِهِ وَلَيْلَتِهِ فَمَاتَ فِي ذَلِكَ الْيَوْمِ أَوْ تِلْكَ اللَّيْلَةِ دَخَلَ الْجَنَّةَ إِنْ شَاءَ اللَّهُ تَعَالَى ‏"‏ ‏.‏\hadithno{3872}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that :his father said: "The Messenger of Allah (saas) said: Allahumma Anta Rabbi la ilaha illa Anta, khalaqtani wa ana 'abduka wa ana 'ala 'ahdika wa wa'dika mastata'tu. A'udhu bika min sharri ma sana'tu, abu'u bi ni'matika wa abu'u bi dhanbi faghfirli, fa innahu la yaghfirudh-dhunuba illa Anta (O Allah, You are my Lord, there is none worthy of worship except You. You have created me and I am Your slave, and I am adhering to Your covenant and Your promise as much as I can. I seek refuge with You from the evil of what I do. I acknowledge Your blessing and I acknowledge my sin, so forgive me, for there is none who can forgive sin except You)."He said: "The Messenger of Allah (saas) said: 'Whoever says this by day and by night, if he dies that day or that night, he will enter Paradise if Allah wills}}
\hadithdefcmd{ibnmajah}{3873}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ يَقُولُ إِذَا أَوَى إِلَى فِرَاشِهِ ‏ "‏ اللَّهُمَّ رَبَّ السَّمَوَاتِ وَرَبَّ الأَرْضِ وَرَبَّ كُلِّ شَىْءٍ فَالِقَ الْحَبِّ وَالنَّوَى مُنْزِلَ التَّوْرَاةِ وَالإِنْجِيلِ وَالْقُرْآنِ الْعَظِيمِ أَعُوذُ بِكَ مِنْ شَرِّ كُلِّ دَابَّةٍ أَنْتَ آخِذٌ بِنَاصِيَتِهَا أَنْتَ الأَوَّلُ فَلَيْسَ قَبْلَكَ شَىْءٌ وَأَنْتَ الآخِرُ فَلَيْسَ بَعْدَكَ شَىْءٌ وَأَنْتَ الظَّاهِرُ فَلَيْسَ فَوْقَكَ شَىْءٌ وَأَنْتَ الْبَاطِنُ فَلَيْسَ دُونَكَ شَىْءٌ اقْضِ عَنِّي الدَّيْنَ وَأَغْنِنِي مِنَ الْفَقْرِ ‏"‏ ‏.‏\hadithno{3873}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that :when going to bed, the Prophet (saas) used to say: "Allahumma Rabbas-samawati wa Rabbal-ardi, wa Rabba kulli shay'in, faliqal-habbi wan-nawa, munzilat-Tawrati wal-Injili wal-Qur'anil-'Azim. A'udhu bika min sharri kulli dabbatin Anta akhidhun binasiyatiha, Antal-Awwalu fa laysa qablaka shayun, wa Antal-Akhiru, fa laysa ba'daka shayun', Antaz-zahiru, fa laysa fawqaka shayun', wa antal-batinu fa laysa dunaka shay', aqdi 'annid-dayna waghnini minal-faqr (O Allah, Lord of the heavens and Lord of the earth and Lord of all things, Cleaver of the seed and the kernel, Revealer of the Tawrah, the Injil and the Magnificent Qur'an, I seek refuge with You from the evil of every creature You seize by the forelock. You are the First and there is nothing before You; You are the Last and there is nothing after You; You are the Most High (Az-Zahir) and there is nothing above You, and You are the Most Near (Al-Batin) and there is nothing nearer than You. Settle my debt for me and spare me from poverty}}
\hadithdefcmd{ibnmajah}{3874}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا أَرَادَ أَحَدُكُمْ أَنْ يَضْطَجِعَ عَلَى فِرَاشِهِ فَلْيَنْزِعْ دَاخِلَةَ إِزَارِهِ ثُمَّ لْيَنْفُضْ بِهَا فِرَاشَهُ فَإِنَّهُ لاَ يَدْرِي مَا خَلَفَهُ عَلَيْهِ ثُمَّ لْيَضْطَجِعْ عَلَى شِقِّهِ الأَيْمَنِ ثُمَّ لْيَقُلْ رَبِّ بِكَ وَضَعْتُ جَنْبِي وَبِكَ أَرْفَعُهُ فَإِنْ أَمْسَكْتَ نَفْسِي فَارْحَمْهَا وَإِنْ أَرْسَلْتَهَا فَاحْفَظْهَا بِمَا حَفِظْتَ بِهِ عِبَادَكَ الصَّالِحِينَ ‏"‏ ‏.‏\hadithno{3874}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah (saas) said: "When anyone of you wants to go to bed, let him undo the edge of his Izar (waist wrap) and dust of his bed with it, for he does not know what came to it after him. Then let him lie down on his right side and say: 'Rabbi bika wada'tu janbi wa bika arfa'uhu, fa in amsakta nafsi farhamha, wa in arsaltaha fahfazha bima hafizta bihi 'ibadikaas-salihin (O Lord, by Your leave I lie down and by Your leave I rise, so if You should take my soul then have mercy on it, and if You should return my soul then protect it as You protect Your righteous slaves)}}
\hadithdefcmd{ibnmajah}{3875}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، وَسَعِيدُ بْنُ شُرَحْبِيلَ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، أَخْبَرَهُ عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَخَذَ مَضْجَعَهُ نَفَثَ فِي يَدَيْهِ وَقَرَأَ بِالْمُعَوِّذَتَيْنِ وَمَسَحَ بِهِمَا جَسَدَهُ ‏.‏\hadithno{3875}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah that:whenever the Prophet (saas) went to bed, he would blow into his hands, recite Al-Mu'awwidhatain, then wipe his hands over his body}}
\hadithdefcmd{ibnmajah}{3876}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لِرَجُلٍ ‏ "‏ إِذَا أَخَذْتَ مَضْجَعَكَ أَوْ أَوَيْتَ إِلَى فِرَاشِكَ فَقُلِ اللَّهُمَّ أَسْلَمْتُ وَجْهِي إِلَيْكَ وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ رَغْبَةً وَرَهْبَةً إِلَيْكَ لاَ مَلْجَأَ وَلاَ مَنْجَى مِنْكَ إِلاَّ إِلَيْكَ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ وَنَبِيِّكَ الَّذِي أَرْسَلْتَ فَإِنْ مِتَّ مِنْ لَيْلَتِكَ مِتَّ عَلَى الْفِطْرَةِ وَإِنْ أَصْبَحْتَ أَصْبَحْتَ وَقَدْ أَصَبْتَ خَيْرًا كَثِيرًا ‏"‏ ‏.‏\hadithno{3876}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Bara' bin 'Azib that :the Prophet (saas) said to a man: "When you go to lay down, or go to your bed, say: Allahumma aslamtu wajhi ilayka, wa al-ja'tu zahri ilayka, wa fawwadtu amri ilayka, raghbatan wa rahbatan ilayka, la malja'a wa la manja'a minka illa ilayka, amantu bi kitabikal-ladhi anzalta, wa nabiyyikal arsalta [O Allah, I have submitted my face (i.e., myself) to You, and I am under Your command (i.e., I depend upon You in all my affairs), and I put my trust in You, hoping for Your reward and fearing Your punishment. There is no fleeing from You and no refuge from You except with You. I believe in Your Book that You have revealed and in Your Prophet whom You have sent).' Then if you die that night, you will die in a state of the Fitrah (nature), and if you wake in the morning you will wake with a great deal of good}}
\hadithdefcmd{ibnmajah}{3877}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَوَى إِلَى فِرَاشِهِ وَضَعَ يَدَهُ - يَعْنِي الْيُمْنَى - تَحْتَ خَدِّهِ ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ قِنِي عَذَابَكَ يَوْمَ تَبْعَثُ - أَوْ تَجْمَعُ - عِبَادَكَ ‏"‏ ‏.‏\hadithno{3877}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that:whenever the Prophet (saas) went to his bed, he would put his hand - meaning his right hand - beneath his cheek then say: "Allahumma qini 'adhabaka yawm tab'athu - [or: tajma'u] - 'ibadaka (O Allah, save me from Your punishment on the Day when You resurrect - or gather - Your slaves)}}
\hadithdefcmd{ibnmajah}{3878}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي عُمَيْرُ بْنُ هَانِئٍ، حَدَّثَنِي جُنَادَةُ بْنُ أَبِي أُمَيَّةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ تَعَارَّ مِنَ اللَّيْلِ فَقَالَ حِينَ يَسْتَيْقِظُ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ الْعَلِيِّ الْعَظِيمِ ثُمَّ دَعَا رَبِّ اغْفِرْ لِي - غُفِرَ لَهُ ‏"‏ ‏.‏ قَالَ الْوَلِيدُ أَوْ قَالَ ‏"‏ دَعَا اسْتُجِيبَ لَهُ فَإِنْ قَامَ فَتَوَضَّأَ ثُمَّ صَلَّى قُبِلَتْ صَلاَتُهُ ‏"‏ ‏.‏\hadithno{3878}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Ubadah bin As-Samit said:“The Messenger of Allah (ﷺ) said: ‘Whoever wakes up in the morning and says upon waking: La ilaha illallah wahdahu la sharika lahu, lahul-mulku wa lahul-hamdu, wa Huwa ‘ala kulli shay’in Qadir; Subhan-Allah walhamdu lillahi, wa la ilaha illallahu, wa Allahu Akbar, wa la hawla wa la quwwata illa billahil-‘Aliyil-‘Azim (None has the right to be worshipped but Allah alone, with no partner or associate. His is the dominion and all praise is to Him, and He is Able to do all things. Glory is to Allah, praise is to Allah, none has the right to be worshiped but Allah, Allah is the Most Great, and there is no power and no strength except with Allah, the Most High, the Most Supreme), then he supplicates Rabbighfirli (O Lord, forgive me), he will be forgiven.’” Walid said: “Or he said: then if he supplicated, it will be answered for him then if he stood up and performed ablution and then performed prayer, his prayer would be accepted.”}}
\hadithdefcmd{ibnmajah}{3879}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، أَنْبَأَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّ رَبِيعَةَ بْنَ كَعْبٍ الأَسْلَمِيَّ، أَخْبَرَهُ أَنَّهُ، كَانَ يَبِيتُ عِنْدَ بَابِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَكَانَ يَسْمَعُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ مِنَ اللَّيْلِ ‏"‏ سُبْحَانَ اللَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏ الْهَوِيَّ ثُمَّ يَقُولُ ‏"‏ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ ‏"‏ ‏.‏\hadithno{3879}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Rabi’ah bin Ka’b Al-Aslami narrated that he used to spend the night outside the door of the Messenger of Allah (ﷺ), and he used to hear the Messenger of Allah (ﷺ) saying at night:“Subhan Allahi Rabbil-‘alamin (Glory is to Allah, the Lord of the worlds),” repeating that for a while, then he said: Subhan Allahi wa bihamdihi (Glory and praise is to Allah).”}}
\hadithdefcmd{ibnmajah}{3880}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا انْتَبَهَ مِنَ اللَّيْلِ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏ ‏.‏\hadithno{3880}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Hudhaifah said:“Whenever the Messenger of Allah (ﷺ) woke up in the morning, he would say: ‘Al-hamdu lillahil-ladhi ahyana ba’dama amatana wa ilayhi’n-nushur (Praise is to Allah Who has given us life after taking it from us, and unto Him is the Resurrection).’”}}
\hadithdefcmd{ibnmajah}{3881}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو الْحُسَيْنِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي ظَبْيَةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ عَبْدٍ بَاتَ عَلَى طُهُورٍ ثُمَّ تَعَارَّ مِنَ اللَّيْلِ فَسَأَلَ اللَّهَ شَيْئًا مِنْ أَمْرِ الدُّنْيَا أَوْ مِنْ أَمْرِ الآخِرَةِ إِلاَّ أَعْطَاهُ ‏"‏ ‏.‏\hadithno{3881}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mu’adh bin Jabal that the Messenger of Allah (ﷺ) said:“There is no person who goes to bed in a state of purity, then wakes up at night, and asks Allah for something in this world or the Hereafter, but it will be given to him.”}}
\hadithdefcmd{ibnmajah}{3882}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، حَدَّثَنِي هِلاَلٌ، مَوْلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ أُمِّهِ، أَسْمَاءَ ابْنَةِ عُمَيْسٍ قَالَتْ عَلَّمَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ كَلِمَاتٍ أَقُولُهُنَّ عِنْدَ الْكَرْبِ ‏ "‏ اللَّهُ اللَّهُ رَبِّي لاَ أُشْرِكُ بِهِ شَيْئًا ‏"‏ ‏.‏\hadithno{3882}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Asma’ bint ‘Umais said:“The Messenger of Allah (ﷺ) taught me some words to say at times of distress: Allah! Allahu Rabbi la ushriku bihi shay’an (Allah, Allah is my Lord, I do not associate anything with Him).”}}
\hadithdefcmd{ibnmajah}{3883}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، صَاحِبِ الدَّسْتَوَائِيِّ عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ عِنْدَ الْكَرْبِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ الْحَلِيمُ الْكَرِيمُ سُبْحَانَ اللَّهِ رَبِّ الْعَرْشِ الْعَظِيمِ سُبْحَانَ اللَّهِ رَبِّ السَّمَوَاتِ السَّبْعِ وَرَبِّ الْعَرْشِ الْكَرِيمِ ‏"‏ ‏.‏ قَالَ وَكِيعٌ مَرَّةً لاَ إِلَهَ إِلاَّ اللَّهُ فِيهَا كُلِّهَا ‏.‏\hadithno{3883}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) used to say at times of distress:“La ilaha illallahul-Halimul-Karim, Subhan-Allahi Rabbil-‘Arshil-‘Azim, Subhan-Allahi Rabbil-samawatis-sab’i wa Rabbil-‘Arshil-Azim (None has the right to be worshipped but Allah, the Forbearing, the Most Generous; glory is to Allah the Lord of the Mighty Throne; glory is to Allah, the Lord of the seven heavens and the Lord of the Magnificent Throne).” Waki’ said with each wording La ilaha illallahu (none has the right to be worshipped but Allah) is to be included}}
\hadithdefcmd{ibnmajah}{3884}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنْ أُمِّ سَلَمَةَ، ‏.‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا خَرَجَ مِنْ مَنْزِلِهِ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ أَنْ أَضِلَّ أَوْ أَزِلَّ أَوْ أَظْلِمَ أَوْ أُظْلَمَ أَوْ أَجْهَلَ أَوْ يُجْهَلَ عَلَىَّ ‏"‏ ‏.‏\hadithno{3884}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that whenever he left his house, the Prophet (ﷺ) would say:“Allahumma inni a’udhu bika an adilla aw azilla, aw azlima aw uzlama, aw ajhala aw yujhala ‘alayya (O Allah, I seek refuge with You from going astray or stumbling, from wronging others or being wronged, and from behaving or being treated in an ignorant manner).”}}
\hadithdefcmd{ibnmajah}{3885}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ حُسَيْنِ بْنِ عَطَاءِ بْنِ يَسَارٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا خَرَجَ مِنْ بَيْتِهِ قَالَ ‏ "‏ بِسْمِ اللَّهِ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ التُّكْلاَنُ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3885}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that whenever he left his house, the Prophet (ﷺ) would say:“Bismillah, la hawla wa la quwwata illa billah, at-tuklanu ‘ala Allah (In the Name of Allah, there is no power and strength except with Allah, and trust is placed in Allah).”}}
\hadithdefcmd{ibnmajah}{3886}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي هَارُونُ بْنُ هَارُونَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا خَرَجَ الرَّجُلُ مِنْ بَابِ بَيْتِهِ - أَوْ مِنْ بَابِ دَارِهِ - كَانَ مَعَهُ مَلَكَانِ مُوَكَّلاَنِ بِهِ فَإِذَا قَالَ بِسْمِ اللَّهِ ‏.‏ قَالاَ هُدِيتَ ‏.‏ وَإِذَا قَالَ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ قَالاَ وُقِيتَ ‏.‏ وَإِذَا قَالَ تَوَكَّلْتُ عَلَى اللَّهِ قَالاَ كُفِيتَ قَالَ فَيَلْقَاهُ قَرِينَاهُ فَيَقُولاَنِ مَاذَا تُرِيدَانِ مِنْ رَجُلٍ قَدْ هُدِيَ وَكُفِيَ وَوُقِيَ ‏"‏ ‏.‏\hadithno{3886}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“When a man goes out of the door of his house, there are two angels with him who are appointed over him. If he says Bismillah (in the Name of Allah) they say: ‘You have been guided.’ If he says La hawla wa la quwwata illa billah (there is no power and no strength except with Allah), they say: ‘You are protected.’ If he says, Tawwakaltu ‘ala Allah (I have my trust in Allah), they say: ‘You have been taken care of.’ Then his two Qarins (satans) come to him and they (the two angels) say: ‘What do you want with a man who has been guided, protected and taken care of?’”}}
\hadithdefcmd{ibnmajah}{3887}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا دَخَلَ الرَّجُلُ بَيْتَهُ فَذَكَرَ اللَّهَ عِنْدَ دُخُولِهِ وَعِنْدَ طَعَامِهِ قَالَ الشَّيْطَانُ لاَ مَبِيتَ لَكُمْ وَلاَ عَشَاءَ ‏.‏ وَإِذَا دَخَلَ وَلَمْ يَذْكُرِ اللَّهَ عِنْدَ دُخُولِهِ قَالَ الشَّيْطَانُ أَدْرَكْتُمُ الْمَبِيتَ ‏.‏ فَإِذَا لَمْ يَذْكُرِ اللَّهَ عِنْدَ طَعَامِهِ قَالَ أَدْرَكْتُمُ الْمَبِيتَ وَالْعَشَاءَ ‏"‏ ‏.‏\hadithno{3887}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that he heard the Prophet (ﷺ) say:“When a man enters his house, and remembers Allah when he enters and when he eats, Satan says: ‘You have no place to stay and no supper.’ If he enters his house and does not remember Allah upon entering, Satan says: ‘You have found a place to stay.’ And if he does not remember Allah when he eats, (Satan) says: ‘You have found a place to stay and supper.’”}}
\hadithdefcmd{ibnmajah}{3888}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، وَأَبُو مُعَاوِيَةَ عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ - وَقَالَ عَبْدُ الرَّحِيمِ يَتَعَوَّذُ - إِذَا سَافَرَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ وَالْحَوْرِ بَعْدَ الْكَوْرِ وَدَعْوَةِ الْمَظْلُومِ وَسُوءِ الْمَنْظَرِ فِي الأَهْلِ وَالْمَالِ ‏"‏ ‏.‏ وَزَادَ أَبُو مُعَاوِيَةَ فَإِذَا رَجَعَ قَالَ مِثْلَهَا ‏.‏\hadithno{3888}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Sarjis said:“The Messenger of Allah (ﷺ) used to say” – and (one of the narrators) ‘Abdur-Rahim said: “he used to seek refuge” – “when he traveled: ‘Allahumma inni a’udhu bika min wa’tha’is-safar, wa ka’abatil-munqalab, wal-hawri ba’dal-kawr, wa da’watil-mazlum, wa su’il-manzari fil-ahli wal-mal (O Allah, I seek refuge with You from the hardships of travel and the sorrows of return, from decrease after increase, from the prayer of the one who has been wronged, and seeing some calamity befall my family or wealth).’” (One of the narrators) Abu Mu’awiyah added: “And when he returned he said likewise.”}}
\hadithdefcmd{ibnmajah}{3889}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ الْمِقْدَامِ، عَنْ أَبِيهِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا رَأَى سَحَابًا مُقْبِلاً مِنْ أُفُقٍ مِنَ الآفَاقِ تَرَكَ مَا هُوَ فِيهِ وَإِنْ كَانَ فِي صَلاَتِهِ حَتَّى يَسْتَقْبِلَهُ فَيَقُولُ ‏"‏ اللَّهُمَّ إِنَّا نَعُوذُ بِكَ مِنْ شَرِّ مَا أُرْسِلَ بِهِ ‏"‏ ‏.‏ فَإِنْ أَمْطَرَ قَالَ ‏"‏ اللَّهُمَّ سَيْبًا نَافِعًا ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثَةً وَإِنْ كَشَفَهُ اللَّهُ عَزَّ وَجَلَّ وَلَمْ يُمْطِرْ حَمِدَ اللَّهَ عَلَى ذَلِكَ ‏.‏\hadithno{3889}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Aishah narrated that when the Prophet (ﷺ) saw a cloud approaching from any horizon, he would stop what he was doing, even if he was praying, and turn to face it, then he would say:“Allahumma inna na’udhu bika min sharri ma ursila bihi (O Allah, we seek refuge with You from the evil of that with which it is sent).” Then if it rained he would say: “Allahumma sayyiban nafi’an (O Allah, a beneficial rain),” two or three times. And if Allah dispelled it and it did not rain, he would praise Allah for that}}
\hadithdefcmd{ibnmajah}{3890}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبِ بْنِ أَبِي الْعِشْرِينَ، حَدَّثَنَا الأَوْزَاعِيُّ، أَخْبَرَنِي نَافِعٌ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، أَخْبَرَهُ عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا رَأَى الْمَطَرَ قَالَ ‏ "‏ اللَّهُمَّ اجْعَلْهُ صَيِّبًا هَنِيئًا ‏"‏ ‏.‏\hadithno{3890}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Aishah that when the Messenger of Allah (ﷺ) saw rain, he would say:“Allahumma aj’alhu sayyiban hani’an (O Allah, make it a wholesome rain cloud).”}}
\hadithdefcmd{ibnmajah}{3891}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا رَأَى مَخِيلَةً تَلَوَّنَ وَجْهُهُ وَتَغَيَّرَ وَدَخَلَ وَخَرَجَ وَأَقْبَلَ وَأَدْبَرَ فَإِذَا أَمْطَرَتْ سُرِّيَ عَنْهُ ‏.‏ قَالَ فَذَكَرَتْ لَهُ عَائِشَةُ بَعْضَ مَا رَأَتْ مِنْهُ فَقَالَ ‏"‏ وَمَا يُدْرِيكِ لَعَلَّهُ كَمَا قَالَ قَوْمُ هُودٍ ‏\{فَلَمَّا رَأَوْهُ عَارِضًا مُسْتَقْبِلَ أَوْدِيَتِهِمْ قَالُوا هَذَا عَارِضٌ مُمْطِرُنَا بَلْ هُوَ مَا اسْتَعْجَلْتُمْ بِهِ \}‏ ‏"‏ ‏.‏ الآيَةَ\hadithno{3891}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“If the Messenger of Allah (ﷺ) saw a cloud that looked as if it was bringing rain, the color of his face would change, and he would go in and out and walk to and fro. Then, if it rained, he would feel relieved.” ‘Aishah mentioned to him what she had seen him do, and he said: “How do you know? Perhaps it would be as the people of Hud said: ‘Then, when they saw it as a dense cloud coming towards their valleys, they said: “This is a cloud bringing us rain!” Nay, but it is that (torment) which you were asking to be hastened.” [46:]}}
\hadithdefcmd{ibnmajah}{3892}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ خَارِجَةَ بْنِ مُصْعَبٍ، عَنْ أَبِي يَحْيَى، عَمْرِو بْنِ دِينَارٍ - وَلَيْسَ بِصَاحِبِ ابْنِ عُيَيْنَةَ - مَوْلَى آلِ الزُّبَيْرِ عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ فَجِئَهُ صَاحِبُ بَلاَءٍ فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي عَافَانِي مِمَّا ابْتَلاَكَ بِهِ وَفَضَّلَنِي عَلَى كَثِيرٍ مِمَّنْ خَلَقَ تَفْضِيلاً - عُوفِيَ مِنْ ذَلِكَ الْبَلاَءِ كَائِنًا مَا كَانَ ‏"‏ ‏.‏\hadithno{3892}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Whoever unexpectedly comes across a person suffering a calamity, and says: Al-hamdu Lillahil-ladhi ‘afani mim-mabtalaka bihi, wa faddalani ‘ala kathirin mimman khalaqa tafdila (Praise is to Allah Who has kept me safe from that which has afflicted you and preferred me over many of those whom He has created), will be kept safe from that calamity, no matter what it is.’”}}
